Commit-ID:  d6b1e9119787fd2e31dcf0f0ce90b71197604206
Gitweb:     http://git.kernel.org/tip/d6b1e9119787fd2e31dcf0f0ce90b71197604206
Author:     Thomas Gleixner <t...@linutronix.de>
AuthorDate: Fri, 7 Feb 2014 20:58:40 +0100
Committer:  Ingo Molnar <mi...@kernel.org>
CommitDate: Sat, 22 Feb 2014 18:08:43 +0100

sched: Adjust p->sched_reset_on_fork when nothing else changes

If the policy and priority remain unchanged a possible modification of
p->sched_reset_on_fork gets lost in the early exit path.

Signed-off-by: Thomas Gleixner <t...@linutronix.de>
[ Rebase ontop of v3.14-rc1. ]
Signed-off-by: Sebastian Andrzej Siewior <bige...@linutronix.de>
Signed-off-by: Peter Zijlstra <pet...@infradead.org>
Link: 
http://lkml.kernel.org/r/1391803122-4425-5-git-send-email-bige...@linutronix.de
Signed-off-by: Ingo Molnar <mi...@kernel.org>
---
 kernel/sched/core.c | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/kernel/sched/core.c b/kernel/sched/core.c
index c94e851..771eb87 100644
--- a/kernel/sched/core.c
+++ b/kernel/sched/core.c
@@ -3362,7 +3362,8 @@ recheck:
        }
 
        /*
         * If not changing anything there's no need to proceed further:
         */
        if (unlikely(policy == p->policy)) {
                if (fair_policy(policy) && attr->sched_nice != task_nice(p))
@@ -3372,6 +3373,7 @@ recheck:
                if (dl_policy(policy))
                        goto change;
 
+               p->sched_reset_on_fork = reset_on_fork;
                task_rq_unlock(rq, p, &flags);
                return 0;
        }
@@ -3362,7 +3362,8 @@ recheck:
 
        /*
-        * If not changing anything there's no need to proceed further:
+        * If not changing anything there's no need to proceed further,
+        * but store a possible modification of reset_on_fork.
         */
        if (unlikely(policy == p->policy)) {
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to